(this["webpackJsonpstreamlit-g2"]=this["webpackJsonpstreamlit-g2"]||[]).push([[0],{54:function(module,__webpack_exports__,__webpack_require__){"use strict";__webpack_require__.d(__webpack_exports__,"a",(function(){return G2}));var react__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(17),react__WEBPACK_IMPORTED_MODULE_0___default=__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__),streamlit_component_lib__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(49),_berryv_g2_react__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(93),react_jsx_runtime__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(37),react_jsx_runtime__WEBPACK_IMPORTED_MODULE_3___default=__webpack_require__.n(react_jsx_runtime__WEBPACK_IMPORTED_MODULE_3__);const SEP="!!-_-____-_-!!";function getDefaultTheme(_){return"dark"===(null===_||void 0===_?void 0:_.base)?"dark":"light"}function processJSString(options){if("string"===typeof options&&options.includes(SEP))return eval(options.replaceAll("!!-_-____-_-!!",""));if(Array.isArray(options))return options.map((_=>processJSString(_)));if("object"===typeof options){const _={...options};for(const e in options)Object.prototype.hasOwnProperty.call(options,e)&&(_[e]=processJSString(options[e]));return _}return options}const G2Component=_=>{const{theme:e,args:t}=_,{style:r,options:o}=t,n=processJSString(o);return Object(react_jsx_runtime__WEBPACK_IMPORTED_MODULE_3__.jsx)(_berryv_g2_react__WEBPACK_IMPORTED_MODULE_2__.a,{style:{width:"100%",height:400,...r},options:{theme:getDefaultTheme(e),...n},onInit:()=>streamlit_component_lib__WEBPACK_IMPORTED_MODULE_1__.a.setFrameHeight()})},G2=Object(streamlit_component_lib__WEBPACK_IMPORTED_MODULE_1__.b)(G2Component)},64:function(_,e,t){"use strict";t.r(e);t(17);var r=t(53),o=t.n(r),n=t(54),i=t(37);o.a.render(Object(i.jsx)(n.a,{}),document.getElementById("root"))}},[[64,1,2]]]);
//# sourceMappingURL=main.d02628f0.chunk.js.map